@@ -3,7 +3,7 @@ from cms.cms_toolbar import ADMIN_MENU_IDENTIFIER, ADMINISTRATION_BREAK
 from cms.toolbar.items import Break
 from cms.toolbar_base import CMSToolbar
 from cms.toolbar_pool import toolbar_pool
-from django.core.urlresolvers import reverse
+from cms.utils.urlutils import admin_reverse
 from django.utils.translation import ugettext_lazy as _
 
 SAMPLEAPP_BREAK = 'Sample App Break'
@@ -19,5 +19,5 @@ class CategoryToolbar(CMSToolbar):
         else:
             position = 0
         category_menu = admin_menu.get_or_create_menu('category', _('Category'), position=position)
-        category_menu.add_sideframe_item(_('Categories'), url=reverse('admin:sampleapp_category_changelist'))
-        category_menu.add_modal_item(_('Add Category'), url=reverse('admin:sampleapp_category_add'))
+        category_menu.add_sideframe_item(_('Categories'), url=admin_reverse('sampleapp_category_changelist'))
+        category_menu.add_modal_item(_('Add Category'), url=admin_reverse('sampleapp_category_add'))
