@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import patterns, url
 
 """
 Also used in cms.tests.ApphooksTestCase
