@@ -6,11 +6,12 @@ from cms.apphook_pool import apphook_pool
 from cms.appresolver import get_app_patterns
 from cms.views import details
 
-
+# This is a constant, really, but must live here due to import order
+SLUG_REGEXP = '[0-9A-Za-z-_.//]+'
 if settings.APPEND_SLASH:
-    regex = r'^(?P<slug>[0-9A-Za-z-_.//]+)/$'
+    regexp = r'^(?P<slug>%s)/$' % SLUG_REGEXP
 else:
-    regex = r'^(?P<slug>[0-9A-Za-z-_.//]+)$'
+    regexp = r'^(?P<slug>%s)/$' % SLUG_REGEXP
 
 if apphook_pool.get_apphooks():
     # If there are some application urls, use special resolver,
@@ -20,6 +21,6 @@ else:
     urlpatterns = []
 
 urlpatterns.extend([
-    url(regex, details, name='pages-details-by-slug'),
+    url(regexp, details, name='pages-details-by-slug'),
     url(r'^$', details, {'slug': ''}, name='pages-root'),
 ])
